@@ -8,7 +8,6 @@
 #' @param config report configuration with function arguments as \link{list}. See details.
 #' @param \dots other arguments to be passed to \link{render}.
 #' @keywords create_report
-#' @aliases GenerateReport
 #' @details \code{config} is a named list to be evaluated by \code{create_report}.
 #' Each name should exactly match a function name.
 #' By doing so, that function and corresponding content will be added to the report.
@@ -26,7 +25,7 @@
 #' }
 #' @importFrom utils browseURL
 #' @importFrom rmarkdown render
-#' @export create_report GenerateReport
+#' @export
 #' @examples
 #' \dontrun{
 #' #############################
@@ -43,11 +42,12 @@
 #'   ),
 #'   "plot_missing" = list(),
 #'   "plot_histogram" = list(),
+#'   "plot_qq" = list(sampled_rows = 1000L),
 #'   "plot_bar" = list(),
-#'   "plot_correlation" = list("use" = "pairwise.complete.obs"),
+#'   "plot_correlation" = list("cor_args" = list("use" = "pairwise.complete.obs")),
 #'   "plot_prcomp" = list(),
 #'   "plot_boxplot" = list(),
-#'   "plot_scatterplot" = list()
+#'   "plot_scatterplot" = list(sampled_rows = 1000L)
 #' )
 #'
 #' # Create report
@@ -57,7 +57,7 @@
 #' # Load library
 #' library(ggplot2)
 #' library(data.table)
-#' data("diamonds", package = "ggplot2")
+#' library(rmarkdown)
 #'
 #' # Set some missing values
 #' diamonds2 <- data.table(diamonds)
@@ -78,56 +78,58 @@
 #'     "introduce" = list(),
 #'     "plot_missing" = list(),
 #'     "plot_histogram" = list(),
-#'     "plot_density" = list(),
+#'     "plot_qq" = list("by" = "cut", sampled_rows = 1000L),
 #'     "plot_bar" = list("with" = "carat"),
-#'     "plot_correlation" = list("use" = "pairwise.complete.obs"),
+#'     "plot_correlation" = list("cor_args" = list("use" = "pairwise.complete.obs")),
 #'     "plot_prcomp" = list(),
-#'     "plot_boxplot" = list("by" = "carat"),
-#'     "plot_scatterplot" = list("by" = "carat")
+#'     "plot_boxplot" = list("by" = "cut")
 #'   ),
 #'   html_document(toc = TRUE, toc_depth = 6, theme = "flatly")
 #' )
 #' }
 
 create_report <- function(data, output_file = "report.html", output_dir = getwd(), y = NULL, config = list(), ...) {
-  ## Check response variable
-  if (!is.null(y)) {
-    if (!(y %in% names(data))) stop("`", y, "` not found in data!")
-  }
-  ## Get directory of report markdown template
-  report_dir <- system.file("rmd_template/report.rmd", package = "DataExplorer")
-  ## Set report configuration if null
-  if (length(config) == 0) {
-    config <- list(
-      "introduce" = list(),
-      "plot_str" = list("type" = "diagonal", "fontSize" = 35, "width" = 1000, "margin" = list("left" = 350, "right" = 250)),
-      "plot_missing" = list(),
-      "plot_histogram" = list(),
-      "plot_bar" = list(),
-      "plot_correlation" = list("use" = "pairwise.complete.obs"),
-      "plot_prcomp" = list(),
-      "plot_boxplot" = list(),
-      "plot_scatterplot" = list()
-    )
-  }
-  ## Render report into html
-  suppressWarnings(render(
-    input = report_dir,
-    output_file = output_file,
-    output_dir = output_dir,
-    intermediates_dir = output_dir,
-    params = list(data = data, report_config = config, response = y),
-    ...
-  ))
-  ## Open report
-  report_path <- file.path(output_dir, output_file)
-  browseURL(report_path)
-  ## Print report directory
-  args <- as.list(match.call())
-  if (ifelse(is.null(args[["quiet"]]), TRUE, !args[["quiet"]])) message(paste0("\n\nReport is generated at \"", report_path, "\"."))
-}
-
-GenerateReport <- function(data, output_file = "report.html", output_dir = getwd(), ...) {
-  .Deprecated("create_report")
-  create_report(data = data, output_file = output_file, output_dir = output_dir, ...)
+	## Check if input is data.table
+	if (!is.data.table(data)) data <- data.table(data)
+	## Check response variable
+	if (!is.null(y)) {
+		if (!(y %in% names(data))) stop("`", y, "` not found in data!")
+	}
+	## Get directory of report markdown template
+	report_dir <- system.file("rmd_template/report.rmd", package = "DataExplorer")
+	## Set report configuration if null
+	if (length(config) == 0) {
+		config <- list(
+			"introduce" = list(),
+			"plot_str" = list(
+				"type" = "diagonal",
+				"fontSize" = 35,
+				"width" = 1000,
+				"margin" = list("left" = 350, "right" = 250)
+			),
+			"plot_missing" = list(),
+			"plot_histogram" = list(),
+			"plot_qq" = list(sampled_rows = 1000L),
+			"plot_bar" = list(),
+			"plot_correlation" = list("cor_args" = list("use" = "pairwise.complete.obs")),
+			"plot_prcomp" = list(),
+			"plot_boxplot" = list(),
+			"plot_scatterplot" = list(sampled_rows = 1000L)
+		)
+	}
+	## Render report into html
+	suppressWarnings(render(
+		input = report_dir,
+		output_file = output_file,
+		output_dir = output_dir,
+		intermediates_dir = output_dir,
+		params = list(data = data, report_config = config, response = y),
+		...
+	))
+	## Open report
+	report_path <- file.path(output_dir, output_file)
+	browseURL(report_path)
+	## Print report directory
+	args <- as.list(match.call())
+	if (ifelse(is.null(args[["quiet"]]), TRUE, !args[["quiet"]])) message(paste0("\n\nReport is generated at \"", report_path, "\"."))
 }
